@@ -1,25 +1,28 @@
-#
-#                _         _    _      _                _    
-#               (_)       | |  | |    | |              | |   
-#  _ __    ___   _  _ __  | |_ | |__  | |  __ _  _ __  | | __
-# | '_ \  / _ \ | || '_ \ | __|| '_ \ | | / _` || '_ \ | |/ /
-# | |_) || (_) || || | | || |_ | |_) || || (_| || | | ||   < 
-# | .__/  \___/ |_||_| |_| \__||_.__/ |_| \__,_||_| |_||_|\_\
-# | |                                                        
-# |_|                                                        
+#------------------------------------------------------------------------------#
 # 
-# This file is part of the 'rich-iannone/pointblank' package.
+#                 _         _    _      _                _    
+#                (_)       | |  | |    | |              | |   
+#   _ __    ___   _  _ __  | |_ | |__  | |  __ _  _ __  | | __
+#  | '_ \  / _ \ | || '_ \ | __|| '_ \ | | / _` || '_ \ | |/ /
+#  | |_) || (_) || || | | || |_ | |_) || || (_| || | | ||   < 
+#  | .__/  \___/ |_||_| |_| \__||_.__/ |_| \__,_||_| |_||_|\_\
+#  | |                                                        
+#  |_|                                                        
+#  
+#  This file is part of the 'rstudio/pointblank' project.
+#  
+#  Copyright (c) 2017-2024 pointblank authors
+#  
+#  For full copyright and license information, please look at
+#  https://rstudio.github.io/pointblank/LICENSE.html
 # 
-# (c) Richard Iannone <riannone@me.com>
-# 
-# For full copyright and license information, please look at
-# https://rich-iannone.github.io/pointblank/LICENSE.html
-#
+#------------------------------------------------------------------------------#
 
 
 #' Perform multiple rowwise validations for joint validity
 #'
-#' @description 
+#' @description
+#' 
 #' The `conjointly()` validation function, the `expect_conjointly()` expectation
 #' function, and the `test_conjointly()` test function all check whether test
 #' units at each index (typically each row) all pass multiple validations. We
@@ -41,16 +44,65 @@
 #' function can be used directly on a data table or with an *agent* object
 #' (technically, a `ptblank_agent` object) whereas the expectation and test
 #' functions can only be used with a data table.
+#' 
+#' @inheritParams col_vals_gt
+#' 
+#' @param ... *Validation expressions*
+#' 
+#'   `<validation expressions>` // **required** (or, use `.list`)
+#' 
+#'   A collection one-sided formulas that consist of validation functions that
+#'   validate row units (the `col_vals_*()` series), column existence
+#'   ([col_exists()]), or column type (the `col_is_*()` series). An example of
+#'   this is `~ col_vals_gte(., a, 5.5), ~ col_vals_not_null(., b`).
+#' 
+#' @param .list *Alternative to `...`*
+#' 
+#'   `<list of multiple expressions>` // **required** (or, use `...`)
+#' 
+#'   Allows for the use of a list as an input alternative to `...`.
+#'
+#' @return For the validation function, the return value is either a
+#'   `ptblank_agent` object or a table object (depending on whether an agent
+#'   object or a table was passed to `x`). The expectation function invisibly
+#'   returns its input but, in the context of testing data, the function is
+#'   called primarily for its potential side-effects (e.g., signaling failure).
+#'   The test function returns a logical value.
+#' 
+#' @section Supported Input Tables:
+#' 
+#' The types of data tables that are officially supported are:
+#' 
+#'  - data frames (`data.frame`) and tibbles (`tbl_df`)
+#'  - Spark DataFrames (`tbl_spark`)
+#'  - the following database tables (`tbl_dbi`):
+#'    - *PostgreSQL* tables (using the `RPostgres::Postgres()` as driver)
+#'    - *MySQL* tables (with `RMySQL::MySQL()`)
+#'    - *Microsoft SQL Server* tables (via **odbc**)
+#'    - *BigQuery* tables (using `bigrquery::bigquery()`)
+#'    - *DuckDB* tables (through `duckdb::duckdb()`)
+#'    - *SQLite* (with `RSQLite::SQLite()`)
+#'    
+#' Other database tables may work to varying degrees but they haven't been
+#' formally tested (so be mindful of this when using unsupported backends with
+#' **pointblank**).
 #'
 #' @section Column Names:
-#' If providing multiple column names in any of the supplied validation steps,
-#' the result will be an expansion of sub-validation steps to that number of
-#' column names. Aside from column names in quotes and in `vars()`,
-#' **tidyselect** helper functions are available for specifying columns. They
-#' are: `starts_with()`, `ends_with()`, `contains()`, `matches()`, and
-#' `everything()`.
+#' 
+#' `columns` may be a single column (as symbol `a` or string `"a"`) or a vector
+#' of columns (`c(a, b, c)` or `c("a", "b", "c")`). `{tidyselect}` helpers
+#' are also supported, such as `contains("date")` and `where(is.double)`. If
+#' passing an *external vector* of columns, it should be wrapped in `all_of()`.
+#' 
+#' When multiple columns are selected by `columns`, the result will be an
+#' expansion of validation steps to that number of columns (e.g.,
+#' `c(col_a, col_b)` will result in the entry of two validation steps).
+#' 
+#' Previously, columns could be specified in `vars()`. This continues to work, 
+#' but `c()` offers the same capability and supersedes `vars()` in `columns`.
 #' 
 #' @section Preconditions:
+#' 
 #' Providing expressions as `preconditions` means **pointblank** will preprocess
 #' the target table during interrogation as a preparatory step. It might happen
 #' that a particular validation requires a calculated column, some filtering of
@@ -69,6 +121,7 @@
 #' be supplied (e.g., `function(x) dplyr::mutate(x, col_b = col_a + 10)`).
 #' 
 #' @section Segments:
+#' 
 #' By using the `segments` argument, it's possible to define a particular
 #' validation with segments (or row slices) of the target table. An optional
 #' expression or set of expressions that serve to segment the target table by
@@ -99,6 +152,7 @@
 #' generate a separate version of the target table.
 #' 
 #' @section Actions:
+#' 
 #' Often, we will want to specify `actions` for the validation. This argument,
 #' present in every validation function, takes a specially-crafted list
 #' object that is best produced by the [action_levels()] function. Read that
@@ -113,7 +167,21 @@
 #' quarter of the total test units fails, the other `stop()`s at the same
 #' threshold level).
 #' 
+#' @section Labels:
+#' 
+#' `label` may be a single string or a character vector that matches the number
+#' of expanded steps. `label` also supports `{glue}` syntax and exposes the
+#' following dynamic variables contextualized to the current step:
+#'   
+#' - `"{.step}"`: The validation step name
+#' - `"{.seg_col}"`: The current segment's column name
+#' - `"{.seg_val}"`: The current segment's value/group
+#'     
+#' The glue context also supports ordinary expressions for further flexibility
+#' (e.g., `"{toupper(.step)}"`) as long as they return a length-1 string.
+#' 
 #' @section Briefs:
+#' 
 #' Want to describe this validation step in some detail? Keep in mind that this
 #' is only useful if `x` is an *agent*. If that's the case, `brief` the agent
 #' with some text that fits. Don't worry if you don't want to do it. The
@@ -121,6 +189,7 @@
 #' then be automatically generated.
 #' 
 #' @section YAML:
+#' 
 #' A **pointblank** agent can be written to YAML with [yaml_write()] and the
 #' resulting YAML can be used to regenerate an agent (with [yaml_read_agent()])
 #' or interrogate the target table (via [yaml_agent_interrogate()]). When
@@ -135,9 +204,9 @@
 #' ```r
 #' agent %>% 
 #'   conjointly(
-#'     ~ col_vals_lt(., columns = vars(a), value = 8),
-#'     ~ col_vals_gt(., columns = vars(c), value = vars(a)),
-#'     ~ col_vals_not_null(., columns = vars(b)),
+#'     ~ col_vals_lt(., columns = a, value = 8),
+#'     ~ col_vals_gt(., columns = c, value = vars(a)),
+#'     ~ col_vals_not_null(., columns = b),
 #'     preconditions = ~ . %>% dplyr::filter(a < 10),
 #'     segments = b ~ c("group_1", "group_2"),
 #'     actions = action_levels(warn_at = 0.1, stop_at = 0.2), 
@@ -152,9 +221,9 @@
 #' steps:
 #' - conjointly:
 #'     fns:
-#'     - ~col_vals_lt(., columns = vars(a), value = 8)
-#'     - ~col_vals_gt(., columns = vars(c), value = vars(a))
-#'     - ~col_vals_not_null(., columns = vars(b))
+#'     - ~col_vals_lt(., columns = a, value = 8)
+#'     - ~col_vals_gt(., columns = c, value = vars(a))
+#'     - ~col_vals_not_null(., columns = b)
 #'     preconditions: ~. %>% dplyr::filter(a < 10)
 #'     segments: b ~ c("group_1", "group_2")
 #'     actions:
@@ -171,21 +240,6 @@
 #' possible to preview the transformation of an agent to YAML without any
 #' writing to disk by using the [yaml_agent_string()] function.
 #'
-#' @inheritParams col_vals_gt
-#' @param ... A collection one-sided formulas that consist of validation
-#'   functions that validate row units (the `col_vals_*()` series), column
-#'   existence ([col_exists()]), or column type (the `col_is_*()` series). An
-#'   example of this is `~ col_vals_gte(., vars(a), 5.5), ~ col_vals_not_null(.,
-#'   vars(b)`).
-#' @param .list Allows for the use of a list as an input alternative to `...`.
-#'
-#' @return For the validation function, the return value is either a
-#'   `ptblank_agent` object or a table object (depending on whether an agent
-#'   object or a table was passed to `x`). The expectation function invisibly
-#'   returns its input but, in the context of testing data, the function is
-#'   called primarily for its potential side-effects (e.g., signaling failure).
-#'   The test function returns a logical value.
-#'
 #' @section Examples:
 #' 
 #' For all examples here, we'll use a simple table with three numeric columns
@@ -216,9 +270,9 @@
 #' agent <-
 #'   create_agent(tbl = tbl) %>%
 #'   conjointly(
-#'     ~ col_vals_lt(., columns = vars(a), value = 8),
-#'     ~ col_vals_gt(., columns = vars(c), value = vars(a)),
-#'     ~ col_vals_not_null(., columns = vars(b))
+#'     ~ col_vals_lt(., columns = a, value = 8),
+#'     ~ col_vals_gt(., columns = c, value = vars(a)),
+#'     ~ col_vals_not_null(., columns = b)
 #'     ) %>%
 #'   interrogate()
 #' ```
@@ -247,9 +301,9 @@
 #' ```{r}
 #' tbl %>%
 #'   conjointly(
-#'     ~ col_vals_lt(., columns = vars(a), value = 8),
-#'     ~ col_vals_gt(., columns = vars(c), value = vars(a)),
-#'     ~ col_vals_not_null(., columns = vars(b))
+#'     ~ col_vals_lt(., columns = a, value = 8),
+#'     ~ col_vals_gt(., columns = c, value = vars(a)),
+#'     ~ col_vals_not_null(., columns = b)
 #'   )
 #' ```
 #'
@@ -261,9 +315,9 @@
 #' ```r
 #' expect_conjointly(
 #'   tbl,
-#'   ~ col_vals_lt(., columns = vars(a), value = 8),
-#'   ~ col_vals_gt(., columns = vars(c), value = vars(a)),
-#'   ~ col_vals_not_null(., columns = vars(b))
+#'   ~ col_vals_lt(., columns = a, value = 8),
+#'   ~ col_vals_gt(., columns = c, value = vars(a)),
+#'   ~ col_vals_not_null(., columns = b)
 #' )
 #' ```
 #' 
@@ -275,9 +329,9 @@
 #' ```{r}
 #' tbl %>%
 #'   test_conjointly(
-#'     ~ col_vals_lt(., columns = vars(a), value = 8),
-#'     ~ col_vals_gt(., columns = vars(c), value = vars(a)),
-#'     ~ col_vals_not_null(., columns = vars(b))
+#'     ~ col_vals_lt(., columns = a, value = 8),
+#'     ~ col_vals_gt(., columns = c, value = vars(a)),
+#'     ~ col_vals_not_null(., columns = b)
 #'   )
 #' ```
 #' 
@@ -370,6 +424,7 @@ conjointly <- function(
 
   # Add one or more validation steps based on the
   # length of `segments_list`
+  label <- resolve_label(label, segments = segments_list)
   for (i in seq_along(segments_list)) {
     
     seg_col <- names(segments_list[i])
@@ -390,7 +445,7 @@ conjointly <- function(
         seg_val = seg_val,
         actions = covert_actions(actions, agent),
         step_id = step_id,
-        label = label,
+        label = label[[i]],
         brief = brief,
         active = active
       )
